#
# Cookbook:: gitlab-ci-runner
# Library:: cookbook_resource
#
# Copyright:: 2020, Ben Hughes <bmhughes@bmhughes.co.uk>, All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

module GitlabCiRunner
  module Cookbook
    # Helpers for cookbook resources
    module ResourceHelpers
      def config_resource_exist?
        begin
          r = find_resource!(:template, new_resource.config_file)
        rescue Chef::Exceptions::ResourceNotFound
          log_chef(:debug, "Template resource #{new_resource.config_file} DOES NOT exist.")
          return false
        end

        unless r.nil?
          log_chef(:debug, "Template resource #{new_resource.config_file} exists.")
          return true
        end

        log_chef(:debug, "Template resource #{new_resource.config_file} DOES NOT exist.")
        false
      end

      def config_resource_create
        log_chef(:info, "Creating resource #{new_resource.config_file}.")

        with_run_context :root do
          find_resource(:chef_gem, 'toml') do
            compile_time true
          end

          cf = edit_resource(:template, new_resource.config_file) do
            source new_resource.template
            cookbook new_resource.cookbook

            owner new_resource.owner
            group new_resource.group
            mode new_resource.mode
            sensitive new_resource.sensitive

            variables['global'] = toml_load(new_resource.config_file).select { |k, _| !k.eql?('runners') }
            variables['runners'] = toml_load(new_resource.config_file).fetch('runners', [])

            helpers(GitlabCiRunner::Cookbook::CommonHelpers)
            helpers(GitlabCiRunner::Cookbook::TomlHelpers)

            action :nothing
            delayed_action :create
          end

          log_chef(:info, "Created resource #{new_resource.config_file}.")
          log_chef(:info, "There are #{cf.variables['runners'].count} runners configured in #{new_resource.config_file}.")
        end
      end

      def config_resource_init
        if config_resource_exist?
          log_chef(:info, "Configuration resource #{new_resource.config_file} present.")
          return false
        end

        config_resource_create
        true
      end

      def hash_keys_string?(hash)
        raise ArgumentError, "Expected Hash, got #{hash.class}." unless hash.is_a?(Hash)

        hash.each_key { |k| return false unless k.is_a?(String) }
        hash.select { |_, v| v.is_a?(Hash) }.each_value { |v| return false unless hash_keys_string?(v) }

        log_chef(:debug, 'Hash key String check passed.')
        true
      end
    end
  end
end
