#
# Cookbook:: gitlab-ci-runner
# Library:: toml
#
# Copyright:: 2020, Ben Hughes <bmhughes@bmhughes.co.uk>, All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

require 'toml'
require_relative '_common'

module GitlabCiRunner
  module Cookbook
    # Helper methods for handling manipulation of config.toml
    module TomlHelpers
      include GitlabCiRunner::Cookbook::CommonHelpers

      def toml_load(file)
        toml = {}

        begin
          toml = ::TOML.load_file(file) if ::File.file?(file)
        rescue NoMethodError
          log_chef(:error, "Failed to read config file: #{file}.")
        end

        log_chef(:info, "Loaded toml file #{file}, content: #{toml}.")

        toml
      end

      def toml_save(config_hash)
        ::TOML::Generator.new(config_hash).body
      end
    end
  end
end
