#
# Cookbook:: gitlab-ci-runner
# Resource:: service
#
# Copyright:: 2020, Ben Hughes <bmhughes@bmhughes.co.uk>
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

property :service_options, Hash, default: {}

action_class do
  def update_service_options
    new_resource.service_options.each do |option, value|
      find_resource!(:service, 'gitlab-runner').send(option, value)
    end
  end
end

action :enable do
  service 'gitlab-runner' do
    supports status: true, restart: true
    action :enable
  end

  update_service_options
end

action :start do
  service 'gitlab-runner' do
    supports status: true, restart: true
    action :nothing
    delayed_action :start
  end

  update_service_options
end

action :restart do
  service 'gitlab-runner' do
    supports status: true, restart: true
    action :nothing
    delayed_action :restart
  end

  update_service_options
end

action :reload do
  service 'gitlab-runner' do
    supports status: true, restart: true
    action :nothing
    delayed_action :reload
  end

  update_service_options
end

action :stop do
  service 'gitlab-runner' do
    supports status: true, restart: true
    action :stop
  end

  update_service_options
end

action :disable do
  service 'gitlab-runner' do
    supports status: true, restart: true
    action :disable
  end

  update_service_options
end
